from .paggf_core import PAGGFCore
from . import paggf_version
from .ui.CID_load_parcel import CIDLoadParcelDlg, CIDLoadParcelFileWidget, \
    CIDLoadParcelManualWidget
from .composer.cid_inventory_generator import CIDPvGenerator
from .ui.welcome import WelcomeCIDDlg
from qgis.core import QgsEditFormConfig
import os.path


class PAGGF_CID(PAGGFCore):
    def __init__(self, iface):
        super(PAGGF_CID, self).__init__(
            iface, paggf_version.CID, 'ID et inventaire TD')

        idc_parcels_layer = self.layers.get("gis", "idc_parcels_to_valid")
        edit_idc_parcel_form_conf = idc_parcels_layer.editFormConfig()
        edit_idc_parcel_form_conf = QgsEditFormConfig(
            edit_idc_parcel_form_conf)
        edit_idc_parcel_form_conf.setUiForm(
            os.path.join(self.plugin_dir, 'ui/CID_inventory_form.ui'))
        edit_idc_parcel_form_conf.setLayout(QgsEditFormConfig.UiFileLayout)
        edit_idc_parcel_form_conf.setInitCodeSource(
            QgsEditFormConfig.CodeSourceFile)
        edit_idc_parcel_form_conf.setInitFilePath(
            os.path.join(self.plugin_dir, 'ui/CID_inventory_form_init.py')
        )
        edit_idc_parcel_form_conf.setInitFunction('on_form_load')

        idc_parcels_layer.setEditFormConfig(edit_idc_parcel_form_conf)

        self.welcome_dlg_class = WelcomeCIDDlg
        self.enable_paggf_action(
            'load_parcel_from_file', {
                'menu_title': 'Charger fichiers de points de sommets ID \
(shp, gpx ou csv)',
                'dlg_class': CIDLoadParcelDlg,
                'load_widget_class': CIDLoadParcelFileWidget,
            })

        self.enable_paggf_action(
            'load_parcel_manually', {
                'menu_title': "Saisir manuellement les coordonnées XY des \
sommets d'une parcelle ID",
                'dlg_class': CIDLoadParcelDlg,
                'load_widget_class': CIDLoadParcelManualWidget,
            })

        self.enable_paggf_action(
            'edit_data',
            {
                'menu_title': "Saisir manuellement le contenu d'un PV CID",
                'pg_schema_name': 'gis',
                'pg_table_name': 'idc_parcels_to_valid'
            })

        self.enable_paggf_action('add_vertex', {})
        self.enable_paggf_action('move_vertex', {})
        self.enable_paggf_action('delete_vertex', {})
        self.enable_paggf_action('add_ring', {})
        self.enable_paggf_action('reshape', {})

        # FIXME
        """
        self.enable_paggf_action('archive_parcel', {
            'pg_schema_name': 'gis',
            'pg_table_name': 'idc_parcels_to_valid'
        })"""

        # FIXME
        """self.enable_paggf_action('copy_parcel', {
            'pg_schema_name': 'gis',
            'pg_table_name': 'current_idc_parcels'
        })"""

        self.enable_paggf_action('pv_upload_signatures', {
            'menu_title': 'Fusion PV ID et scan des signatures',
            'pg_schema_name': 'gis',
            'pg_table_name': 'idc_parcels_to_valid',
            'pv_generator_cls': CIDPvGenerator,
        })

        self.enable_paggf_action('pv_w_signatures_print', {
            'menu_title': 'Génération et impression PV ID',
            'pg_schema_name': 'gis',
            'pg_table_name': 'idc_parcels_to_valid',
            'pv_generator_cls': CIDPvGenerator,
        })

        self.enable_paggf_action('load_attributes_from_file', {
            'menu_title': 'Charger automatiquement les attributs PV CID'
        })

    def paggf_menu_content(self):
        return [  # DEFINITION DE L'ARBRE DU MENU
            # quand (nom, list) = sous menu
            # quand (nom, nom_action) = un access a une action
            ('Géométrie parcelle ID', [
                self.actions['load_parcel_from_file'],  # Charger fichiers
                # de points de sommets ID (shp, gpx ou csv)
                self.actions['load_parcel_manually'],  # Saisir manuellement
                # les coordonnées XY des sommets d'une parcelle ID",
                "Editer et valider la géométrie d'une parcelle ID"
            ]),
            ('Attributs parcelle ID', [
                self.actions['load_attributes_from_file'],
                self.actions['edit_data']
            ]),
            ('Croquis orienté parcelle ID', [
                "Préparer et valider un croquis orienté de parcelle ID",
                "Exporter un croquis ID en pdf ou image"
            ]),
            ('PV parcelle ID', [
                self.actions['pv_w_signatures_print'],  # Génération et
                # impression PV ID
                self.actions['pv_upload_signatures'],  # Fusion PV ID et scan
                # des signatures
            ]),
            ('Rapport communal ID et autres vues/exports', [
                "Edition et impression de l'affichage restitution provisoire",
                "Edition et impression de la carte communale",
                "Exporter le plan global des TDs identifiées par colline",
                "Préparer et exporter/imprimer un extrait de croquis de \
parcelle ID"
            ]),
            ("Consultation et requête inventaire TD communal", [
                "Visualisation synthétique de la BD communale",
                "Requête par attribut"
            ]),
            ("Paramétrage et maintenance BD ID", [
                "Paramétrage BD et plugin ID",
                "Synchronisation avec BD centrale"
            ])
        ]
