import os

from PyQt5 import uic
from PyQt5.QtCore import QSettings
from PyQt5.QtWidgets import QDialog, QFileDialog, QMessageBox
from qgis.core import QgsMessageLog, QgsVectorLayer

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'CID_load_attr_from_shp.ui'))

fields_map_from_to = [
    ('blop', 'manager'),
    ('area', 'area'),
    ('num_parcel', 'num_parcel'),
    ('commission_reference', 'commission_reference'),
]


class LoadAttrFromFile(QDialog, FORM_CLASS):
    def __init__(self, feature_to, layer_to, parent=None):
        # feature_to -> qui va recevoir les données
        # layer_to -> qui va recevoir
        # message_bar -> pour communiquer
        super(LoadAttrFromFile, self).__init__()
        self.setupUi(self)
        self.feature_to = feature_to
        self.layer_to = layer_to

        self.column_from_selector = 'idc_parcel'
        # display this colum to the use for making his choice
        # FIXME if there is more than one feature,

        self.browse_button.clicked.connect(self.file_browse)
        self.load_button.clicked.connect(self.load_attributes_slot)

        self._file_from_path = None
        self._layer_from = None
        self._layer_from_dp = None

    def file_browse(self):
        s = QSettings("PAGGF", "PAGGF")
        last_file_path = s.value("lastPAGGFFileLoaded", ".")

        if not os.path.exists(last_file_path):
            last_file_path = os.getcwd()

        self._file_from_path, _ = QFileDialog.getOpenFileName(
            self, "Fichier contenant les attributs à charger",
            last_file_path, "*.shp *.xls *.xlsx")

        s.setValue("lastPAGGFFileLoaded", self._file_from_path)

        self._layer_from = QgsVectorLayer(
            self._file_from_path, 'load_attibutes_layer', 'ogr')
        self._layer_from_dp = self._layer_from.dataProvider()

        self.update_file_path_field()
        self.update_column_from_selector()

    def update_column_from_selector(self):
        if self._layer_from_dp.fieldNameIndex(self.column_from_selector) != -1:
            if self._layer_from:
                self.feature_selector.clear()
                self.feature_selector.addItem('')
                for f in self._layer_from.getFeatures():
                    self.feature_selector.addItem(
                        str(f[self.column_from_selector]))
        else:
            msg = QMessageBox()
            msg.setText(
                'Le fichier {} ne possède pas de colonne {}'.format(
                    self._file_from_path,
                    self.column_from_selector
                )
            )
            msg.exec_()

    def update_file_path_field(self):
        self.file_path_field.setText(self._file_from_path)

    def load_attributes_slot(self):
        row_selector = self.feature_selector.currentText()

        if row_selector:
            for f in self._layer_from.getFeatures():
                if str(f[self.column_from_selector]) == row_selector:
                    self.load_attributes_from_feature(f)
        else:
            msg = QMessageBox()
            msg.setText("Veuillez choisir l'élément à importer")
            msg.exec_()

    def load_attributes_from_feature(self, feature_from):
        self.layer_to.startEditing()

        layer_from_dp = self._layer_from.dataProvider()
        layer_to_dp = self.layer_to.dataProvider()

        for fieldname_from, fieldname_to in fields_map_from_to:
            fieldfrom_index = layer_from_dp.fieldNameIndex(fieldname_from)
            fieldto_index = layer_to_dp.fieldNameIndex(fieldname_to)

            if fieldfrom_index != -1 and fieldto_index != -1:
                self.layer_to.changeAttributeValue(
                    self.feature_to.id(),
                    fieldto_index,
                    feature_from[fieldname_from])
